Registration on the OSF
=======================

Dallinger integrates with the `Open Science Framework <https://osf.io/>`__
(OSF), creating a new OSF project and uploading your experiment code to the
project on launch. To enable, specify a personal access token ``osf_access_token``
in your ``.dallingerconfig`` file. You can generate a new OSF personal access
token on the `OSF settings page <https://osf.io/settings/tokens/>`__.
